"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileService__Consumer = exports.FileService__Producer = void 0;
const soa_client_1 = require("@cross-lab-project/soa-client");
const soa_client_2 = require("@cross-lab-project/soa-client");
const tiny_typed_emitter_1 = require("tiny-typed-emitter");
const ServiceType = 'https://api.goldi-labs.de/serviceTypes/file';
function checkConfig(config) {
    if (config.serviceType !== ServiceType) {
        //throw Error("Service Configuration needs to be for FileService type");
    }
}
class FileService__Producer {
    constructor(serviceId) {
        this.serviceType = ServiceType;
        this.serviceDirection = soa_client_1.Producer;
        this.serviceId = serviceId;
    }
    getMeta() {
        return {
            serviceType: this.serviceType,
            serviceId: this.serviceId,
            serviceDirection: this.serviceDirection,
        };
    }
    setupConnection(connection, serviceConfig) {
        checkConfig(serviceConfig);
        const channel = new soa_client_2.DataChannel();
        if (connection.tiebreaker) {
            connection.transmit(serviceConfig, 'data', channel);
        }
        else {
            connection.receive(serviceConfig, 'data', channel);
        }
        this.channel = channel;
    }
    async sendFile(fileType, content) {
        if (this.channel !== undefined) {
            await this.channel.ready();
            this.channel.send(JSON.stringify({ fileType: fileType, length: content.length }));
            this.channel.send(content);
        }
    }
}
exports.FileService__Producer = FileService__Producer;
class FileService__Consumer extends tiny_typed_emitter_1.TypedEmitter {
    constructor(serviceId) {
        super();
        this.serviceType = ServiceType;
        this.serviceDirection = soa_client_1.Consumer;
        this.serviceId = serviceId;
    }
    getMeta() {
        return {
            serviceType: this.serviceType,
            serviceId: this.serviceId,
            serviceDirection: this.serviceDirection,
        };
    }
    setupConnection(connection, serviceConfig) {
        checkConfig(serviceConfig);
        const channel = new soa_client_2.DataChannel();
        channel.ondata = this.handleData.bind(this);
        if (connection.tiebreaker) {
            connection.transmit(serviceConfig, 'data', channel);
        }
        else {
            connection.receive(serviceConfig, 'data', channel);
        }
    }
    handleData(data) {
        if (typeof data === 'string') {
            this.header = JSON.parse(data);
        }
        else if (typeof data === 'object' && data instanceof ArrayBuffer) {
            const content = new Uint8Array(data);
            this.emit('file', { file_type: this.header.fileType, file: content });
        }
    }
}
exports.FileService__Consumer = FileService__Consumer;
//# sourceMappingURL=file_service.js.map