import { Consumer, Producer, } from '@cross-lab-project/soa-client';
import { DataChannel } from '@cross-lab-project/soa-client';
import { TypedEmitter } from 'tiny-typed-emitter';
const ServiceType = 'https://api.goldi-labs.de/serviceTypes/file';
function checkConfig(config) {
    if (config.serviceType !== ServiceType) {
        //throw Error("Service Configuration needs to be for FileService type");
    }
}
export class FileService__Producer {
    constructor(serviceId) {
        this.serviceType = ServiceType;
        this.serviceDirection = Producer;
        this.serviceId = serviceId;
    }
    getMeta() {
        return {
            serviceType: this.serviceType,
            serviceId: this.serviceId,
            serviceDirection: this.serviceDirection,
        };
    }
    setupConnection(connection, serviceConfig) {
        checkConfig(serviceConfig);
        const channel = new DataChannel();
        if (connection.tiebreaker) {
            connection.transmit(serviceConfig, 'data', channel);
        }
        else {
            connection.receive(serviceConfig, 'data', channel);
        }
        this.channel = channel;
    }
    async sendFile(fileType, content) {
        if (this.channel !== undefined) {
            await this.channel.ready();
            this.channel.send(JSON.stringify({ fileType: fileType, length: content.length }));
            this.channel.send(content);
        }
    }
}
export class FileService__Consumer extends TypedEmitter {
    constructor(serviceId) {
        super();
        this.serviceType = ServiceType;
        this.serviceDirection = Consumer;
        this.serviceId = serviceId;
    }
    getMeta() {
        return {
            serviceType: this.serviceType,
            serviceId: this.serviceId,
            serviceDirection: this.serviceDirection,
        };
    }
    setupConnection(connection, serviceConfig) {
        checkConfig(serviceConfig);
        const channel = new DataChannel();
        channel.ondata = this.handleData.bind(this);
        if (connection.tiebreaker) {
            connection.transmit(serviceConfig, 'data', channel);
        }
        else {
            connection.receive(serviceConfig, 'data', channel);
        }
    }
    handleData(data) {
        if (typeof data === 'string') {
            this.header = JSON.parse(data);
        }
        else if (typeof data === 'object' && data instanceof ArrayBuffer) {
            const content = new Uint8Array(data);
            this.emit('file', { file_type: this.header.fileType, file: content });
        }
    }
}
//# sourceMappingURL=file_service.js.map